﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Collections.Specialized;
using System.ComponentModel;
using System.Diagnostics;
using System.Globalization;
using System.IO;
using System.Reflection;
using System.Runtime.Serialization;
using System.Runtime.Serialization.Formatters.Binary;
using System.Windows;
using System.Windows.Documents;
using System.Windows.Media;
using System.Windows.Navigation;
using System.Windows.Threading;
using ThinkGeo.Core;
using System.Windows.Forms;

namespace WpfDotNetFramwork
{
    public enum Position { UpperLeft, UpperRight, LowerLeft, LowerRight };
    class CompassAdornmentLayer : AdornmentLayer
    {
        GeoImage needleImage = null;
        GeoImage frameImage = null;
        Position position;
        int sizePercentage;
        float rotateAngle;

        //Use that constructor with only one image for the needle (will work as a simple north arrow)  
        public CompassAdornmentLayer(GeoImage needleImage, Position position, int sizePercentage)
        {
            this.needleImage = needleImage;
            this.position = position;
            this.sizePercentage = sizePercentage;
        }

        //Use that constructor with both images for needle and frame of the compass.  
        public CompassAdornmentLayer(GeoImage needleImage, GeoImage frameImage, Position position, int sizePercentage)
        {
            this.needleImage = needleImage;
            this.frameImage = frameImage;
            this.position = position;
            this.sizePercentage = sizePercentage;
        }

        public GeoImage NeedleImage
        {
            get { return needleImage; }
            set { needleImage = value; }
        }

        public GeoImage FrameImage
        {
            get { return frameImage; }
            set { frameImage = value; }
        }

        //We needs to update that property as the map rotates to have the needle showing the north accurately.  
        public float RotateAngle
        {
            get { return rotateAngle; }
            set { rotateAngle = value; }
        }

        public Position Position
        {
            get { return position; }
            set { position = value; }
        }

        public int SizePercentage
        {
            get { return sizePercentage; }
            set { sizePercentage = value; }
        }

        protected override void DrawCore(GeoCanvas canvas, Collection<SimpleCandidate> labelsInAllLayers)
        {
            RectangleShape WorldExtent = canvas.CurrentWorldExtent;
            GeographyUnit Mapunits = canvas.MapUnit;
           // return;
            int margin = 10;
            int Xloc = 0;
            int Yloc = 0;
            int imageWidth = (sizePercentage * needleImage.Width) / 100;
            int imageHeight = (sizePercentage * needleImage.Height) / 100;
            switch (position)
            {
                case Position.UpperLeft:
                    Xloc = (imageWidth / 2) + margin;
                    Yloc = (imageHeight / 2) + margin;
                    break;
                case Position.UpperRight:
                    Xloc = ((int)canvas.Width - (imageWidth / 2)) - margin;
                    Yloc = (imageHeight / 2) + margin;
                    break;
                case Position.LowerLeft:
                    Xloc = (imageWidth / 2) + margin;
                    Yloc = ((int)canvas.Height - (imageHeight / 2)) - margin;
                    break;
                case Position.LowerRight:
                    Xloc = ((int)canvas.Width - (imageWidth / 2)) - margin;
                    Yloc = ((int)canvas.Height - (imageHeight / 2)) - margin;
                    break;
            }
            if (frameImage != null)
            {
                canvas.DrawScreenImage(frameImage, Xloc, Yloc, imageWidth, imageHeight, DrawingLevel.LevelFour, 0, 0, 0);
                canvas.DrawScreenImage(needleImage, Xloc, Yloc, imageWidth, imageHeight, DrawingLevel.LevelFour, 0, 0, 0); 
            }
        }
    }
}
